Umherirrender has uploaded a new change for review.

  https://gerrit.wikimedia.org/r/55095


Change subject: TimeAdjustTest: Use dataProvider
......................................................................

TimeAdjustTest: Use dataProvider

Also removes setting of wgContLang/wgLanguageCode, because test extends
MediaWiki*Lang*TestCase

Change-Id: I8a24fbe161c8f2ecae7591baf99845ff4434f983
---
M tests/phpunit/includes/TimeAdjustTest.php
1 file changed, 17 insertions(+), 22 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/mediawiki/core 
refs/changes/95/55095/1

diff --git a/tests/phpunit/includes/TimeAdjustTest.php 
b/tests/phpunit/includes/TimeAdjustTest.php
index a58702b..95f600f 100644
--- a/tests/phpunit/includes/TimeAdjustTest.php
+++ b/tests/phpunit/includes/TimeAdjustTest.php
@@ -4,22 +4,27 @@
        protected function setUp() {
                parent::setUp();
 
-               $this->setMwGlobals( array(
-                       'wgLocalTZoffset' => null,
-                       'wgContLang' => Language::factory( 'en' ),
-                       'wgLanguageCode' => 'en',
-               ) );
-
                $this->iniSet( 'precision', 15 );
        }
 
-       # Test offset usage for a given language::userAdjust
-       function testUserAdjust() {
-               global $wgLocalTZoffset, $wgContLang;
+       /**
+        * Test offset usage for a given language::userAdjust
+        * @dataProvider dataUserAdjust
+        */
+       function testUserAdjust( $date, $localTZoffset, $expected ) {
+               global $wgContLang;
 
-               #  Collection of parameters for Language_t_Offset.
-               # Format: date to be formatted, localTZoffset value, expected 
date
-               $userAdjust_tests = array(
+               $this->setMwGlobals( 'wgLocalTZoffset', $localTZoffset );
+
+               $this->assertEquals(
+                       strval( $expected ),
+                       strval( $wgContLang->userAdjust( $date, '' ) ),
+                       "User adjust {$date} by {$localTZoffset} minutes should 
give {$expected}"
+               );
+       }
+
+       function dataUserAdjust() {
+               return array(
                        array( 20061231235959, 0, 20061231235959 ),
                        array( 20061231235959, 5, 20070101000459 ),
                        array( 20061231235959, 15, 20070101001459 ),
@@ -31,15 +36,5 @@
                        array( 20061231235959, -30, 20061231232959 ),
                        array( 20061231235959, -60, 20061231225959 ),
                );
-
-               foreach ( $userAdjust_tests as $data ) {
-                       $wgLocalTZoffset = $data[1];
-
-                       $this->assertEquals(
-                               strval( $data[2] ),
-                               strval( $wgContLang->userAdjust( $data[0], '' ) 
),
-                               "User adjust {$data[0]} by {$data[1]} minutes 
should give {$data[2]}"
-                       );
-               }
        }
 }

-- 
To view, visit https://gerrit.wikimedia.org/r/55095
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I8a24fbe161c8f2ecae7591baf99845ff4434f983
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/core
Gerrit-Branch: master
Gerrit-Owner: Umherirrender <umherirrender_de...@web.de>

_______________________________________________
MediaWiki-commits mailing list
MediaWiki-commits@lists.wikimedia.org
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to